#
# spec file for package greybird-theme
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name Greybird

Name:           greybird-theme
Version:        3.22.11+git4.320a703
Release:        lp152.1.1
URL:            https://github.com/shimmerproject/Greybird
Summary:        A grey theme for GNOME, XFCE, GTK+ 2 and 3
License:        GPL-2.0-or-later OR CC-BY-SA-3.0
Group:          System/GUI/GNOME
Source:         %{_name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gdk-pixbuf-devel
BuildRequires:  gdk-pixbuf-loader-rsvg
BuildRequires:  glib2-devel
BuildRequires:  meson
BuildRequires:  sassc
BuildArch:      noarch

%description
This theme for GTK2/3 and xfwm4/emerald/metacity started out on the basis of
Bluebird, but aims at reworking the intense blue tone to a more neutral
grey-ish look.

%package -n metatheme-greybird-common
Summary:        Common files for the Greybird theme
Group:          System/GUI/GNOME
Suggests:       gtk2-metatheme-greybird
Suggests:       gtk3-metatheme-greybird

%description -n metatheme-greybird-common
The Greybird theme for GTK2/3 and xfwm4/emerald/metacity started out on the
basis of Bluebird, but aims at reworking the intense blue tone to a more
neutral grey-ish look.

This package provides the files common to the GTK+ themes and the window
manager themes as well as background images.

%package -n gtk2-metatheme-greybird
Summary:        GTK+ 2 support for the Greybird theme
Group:          System/GUI/GNOME
Requires:       gtk2-engine-murrine
Requires:       metatheme-greybird-common = %{version}
Supplements:    packageand(metatheme-greybird-common:gtk2)

%description -n gtk2-metatheme-greybird
The Greybird Theme for GTK2/3 and xfwm4/emerald/metacity started out on the
basis of Bluebird, but aims at reworking the intense blue tone to a more
neutral grey-ish look.

This package provides the GTK+ 2 support of Greybird.

%package -n gtk3-metatheme-greybird
Summary:        GTK+ 3 support for the Greybird theme
Group:          System/GUI/GNOME
Requires:       metatheme-greybird-common = %{version}
Supplements:    packageand(metatheme-greybird-common:gtk3)

%description -n gtk3-metatheme-greybird
The Greybird Theme for GTK2/3 and xfwm4/emerald/metacity started out on the
basis of Bluebird, but aims at reworking the intense blue tone to a more
neutral grey-ish look.

This package provides the GTK+ 3 support of Greybird.

%prep
%setup -q -n %{_name}-%{version}

%build
%meson
%meson_build

%install
%meson_install
# remove stuff that's unlikely to be used
rm -r %{buildroot}%{_datadir}/themes/%{_name}{,-dark}/unity
rm -r %{buildroot}%{_datadir}/themes/%{_name}{,-dark}/plank

# the convulted fdupes call is necessary, else a gtk-2.0 icon will be linked to gtk-3.0
# which will not work if only one subpackage is installed.
%fdupes -s %{buildroot}/%{_datadir}/themes/%{_name}*/{[^g]*,gtk-3.0}
%fdupes -s %{buildroot}/%{_datadir}/themes/%{_name}*/gtk-2.0/*

%files -n metatheme-greybird-common
%doc README.md
%license LICENSE.CC LICENSE.GPL
%dir %{_datadir}/themes/%{_name}{,-dark}/
%{_datadir}/themes/%{_name}{,-dark}/metacity-1
%{_datadir}/themes/%{_name}/xfce-notify-4.0
%{_datadir}/themes/%{_name}{,-dark}/xfwm4
%{_datadir}/themes/%{_name}{,-dark}/*.emerald
%{_datadir}/themes/%{_name}{,-dark}/index.theme
%dir %{_datadir}/themes/%{_name}{,-dark}-accessibility
%{_datadir}/themes/%{_name}{,-dark}-accessibility/xfwm4
%dir %{_datadir}/themes/%{_name}-compact
%{_datadir}/themes/%{_name}-compact/xfwm4
%dir %{_datadir}/themes/%{_name}-bright
%{_datadir}/themes/%{_name}-bright/xfce-notify-4.0
%dir %{_datadir}/themes/%{_name}{,-dark}/gnome-shell
%{_datadir}/themes/%{_name}{,-dark}/gnome-shell/gnome-shell.css

%files -n gtk2-metatheme-greybird
%{_datadir}/themes/%{_name}{,-dark}/gtk-2.0

%if 0%{?suse_version} >= 1210
%files -n gtk3-metatheme-greybird
%{_datadir}/themes/%{_name}{,-dark}/gtk-3.0
%endif

%changelog
* Sat Feb 22 2020 tux93@opensuse.org
- Update to version 3.22.11+git4.320a703:
  * Sync dark theme with light theme and use symlink
  * Rebase partly on Adwaita 3.24
  * Messagedialog: Reduce buttonbox button height
  * notifyd: Tweak the theme's appearance (button hover)
  * Hide i/o on GtkSwitches
* Sat Nov 16 2019 maurizio.galli@gmail.com
- Update to version 3.22.10+git17.4d806cd:
  * Fixed xfwm4-a11y dark buttons padding and window borders
  * Added xfwm4 Greybird-accessibility-dark
* Wed Nov  6 2019 tux93@opensuse.org
- Update to version 3.22.10+git15.acede86:
  * Make use of symlinks cleanup unused files
* Mon Nov  4 2019 tux93@opensuse.org
- Update to version 3.22.10+git14.e467f4b:
  * Add single-user installation instructions
  * Fix notification theme paths
  * Include meson as dependency in README.md
  * various small fixes
  * Buildsystem ported to meson and added dark theme
* Thu Oct 24 2019 maurizio.galli@gmail.com
- Update to version 3.22.10~git8.99f40ce:
  * Add minimal size to header bar button's label
  * Revert "Fix size of linked button with images in header bar"
  * xfdesktop: Highlight selected icons
  * Fix size of linked button with images in header bar
  * xfce4-panel: Add drop-target style
  * Improve button sizing
  * Make error and warning entry text more readable
  * Also set backdrop color for print dialog (Fixes #243)
  * Re-apply xfwm4 tabwin sizing improvement (Issue #224)
  * Improve the print dialog's style (Fixes #238)
* Fri May 10 2019 maurizio.galli@gmail.com
- Update to version 3.22.10~git3.c0b8881:
  * Improve button sizing
  * Make error and warning entry text more readable
  * Also set backdrop color for print dialog
    (Fixes gh#shimmerproject/Greybird#243)
* Wed Apr 24 2019 maurizio.galli@gmail.com
- Update to version 3.22.10~git2.799485d:
  * Make error and warning entry text more readable
  * Also set backdrop color for print dialog
    (Fixes gh#shimmerproject/Greybird#243)
  * Re-apply xfwm4 tabwin sizing improvement
    (Issue gh#shimmerproject/Greybird#224)
- Switched sources to git master branch
- Spec file: switched to %%autosetup for simplicity
* Mon Feb 18 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 3.22.10:
  * Improve the print dialog's style (gh#shimmerproject/Greybird#238)
  * Fix glitch in Xfdesktop 4.13 rubberband (gh#shimmerproject/Greybird#234)
  * Apply Xfce Panel Tasklist margin intelligently (gh#shimmerproject/Greybird#240)
  * Make Xfce Panel's Tasklist button's padding consistent
  * Handle carets in entry widgets in Xfce panel plugins (gh#shimmerproject/Greybird#241)
  * Fix xfce4-terminal's tab borders again (gh#shimmerproject/Greybird#184)
  * Re-apply Xfwm4 tabwin sizing improvement (gh#shimmerproject/Greybird#224)
  - Dropped obsolete macros and added minor improvements
* Sat Nov 17 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 3.22.9:
  * Support for Xfwm4 4.13
  * Improve contrast in Xfwm4's alt-tab dialog (both 4.12 and 4.13)
  * Switch from ruby-sass to sassc
  * Fix height thunar's pathbar entry widget
  * Use correct colors for GtkNotebook
  * Fix Chromium's titlebar buttons
  * Make the Gtk3 xfce4-panel 80%% transparent again
  * Improve hidpi support in CSD (gh#shimmerproject/greybird#100)
  * Fix Gtk2 radiobuttons (gh#shimmerproject/greybird#219)
  * Drop superfluous assets
  * Make radio and checkitems more consistent between Gtk2 and Gtk3
  * Improve lightdm-gtk-greeter theming
  * Include Gtk3 window decorations
  * Improve backdrop style of several widgets
- BuildRequires: remove ruby-sass and add  sassc
* Sat Feb 24 2018 cornelis@solcon.nl
- Update to 3.22.6:
  * Improvements for Thunar-gtk3
  * Improvements for xfce4-panel 4.13
  * Implement Chrome/ium Gtk3 style
  * Include dark version of gnome app theming
  * Tweak lightdm-gtk-greeter's restart button"
  * Bugfixes
- Remove gtk3-engine-unico requirement, has not been needed for some
  time
* Mon Dec 11 2017 jengelh@inai.de
- Remove bias from description.
- Update homepage URL. Remove idempotent %%if..%%endif guards.
* Fri Sep 22 2017 p.seiler@linuxmail.org
- updated to current release 3.22.5
- added gnome-shell.css to package
* Mon Dec 26 2016 seife+obs@b1-systems.com
- clarify rubygem-sass BuildRequires version
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to the current release 3.22.0
* Wed Oct  2 2013 seiler@b1-systems.de
- updated th current release v1.2.2-3
* Wed May 15 2013 seiler@b1-systems.de
- updated to lastest release -v1.1.1-5
* Thu Jan 31 2013 seiler@b1-systems.de
- updated to latest release v1.0.8-2
* Mon Jul 16 2012 seiler@b1-systems.de
- updated to latest release (8.2-95)
* Wed Feb  8 2012 seiler@b1-systems.de
- updated to latest release (4.3-6)
- specfile cleanup fo X11:xfce (last submit was not accepted, old submit without the rpm seperation was included)
* Fri Feb  3 2012 gber@opensuse.org
- specfile cleanup
* Wed Feb  1 2012 seiler@b1-systems.de
- updated to latest source
- added fdupes to symlink duplicate files
* Tue Dec  6 2011 seiler@b1-systems.de
- added gtk3 dependencie for openSUSE 12.1
* Tue Dec  6 2011 seiler@b1-systems.de
- fixed syntax error in file section
- modified the custom macros
- updated summary
- modified *.spec file to prevent warnings
- cleaned *.spec file
- updated to the current greybird release
- modified SOURCE0 file with custom macros
